function [hoursprof lfpprof nhoursprof nlfpprof] = EITCSimOLG_iterative(hbar,mu,e0,e1,gamma,tau1,tau2,gens,press,presh)
%EITCSimOLG_iterative: Simulate overlapping generations of EITC using iterative methods
%hbar, mu, e0, e1, gamma, tau given, gens generations and press and presh
%precision for assets and hours

%set up matrices
%time and generations
step=1/gens;
time=0:step:1;
gens=gens+1;

%state and choice vector: assets
smin=-.05;
smax=.05;
svec=[smin:press:smax]';
ss=size(svec); ss=ss(1);

%choice vector: hours
hmin=0;
hmax=.75;
hvec=[hmin:presh:hmax]';
sh=size(hvec); sh=sh(1);

%create two dimensional matrices with st in columns and st+1 %and h in rows,
%with st+1 increasing every element and h increasing every ss elements

stmat=repmat(svec',ss*sh,1);
stp1mat=repmat(svec,sh,ss);
hmat=repmat(hvec(1),ss,ss);
for(j=2:sh)
    hmat=vertcat(hmat,hvec(j)*ones(ss));
end

%matrices--compute once and pass to EITCSim to save time
evec=e0-2*(1-e1)*abs(.5-time); %productivity at age t
ghmat=max(hmat-hbar,0)*(1-tau1)*step; %g(ht)*(1-tau)*step
diffmat=stmat-stp1mat; %difference between stp1 and st
vht=step*mu/(1+gamma)*(hmat.^(1+gamma));%disutility of hours (stationary)
u=@(c) log(max(c,0)); %utility

%hours policy, asset policy, and value function matrices
hoursmat=zeros(ss,gens);
assetsmat=zeros(ss,gens);
choicemat=zeros(ss,gens);
valmat=zeros(ss,gens);

%First simulate the model for the given hbar, e0, e1, gamma, and mu to get
%the asset profile and hours/lfp profiles without the tax change
[ohprof s]=RWSim_iterative(hbar,mu,e0,e1,gamma,tau1,gens,svec,hvec,stp1mat,hmat,ghmat,diffmat,evec,vht,u);

ohprof(time>.5)=0; %only first half of life
ohprof=ohprof';
olprof =(ohprof>0);

hoursprof=zeros(1,gens);
lfpprof=zeros(1,gens);
test=ones(1,gens);
%compute hoursprof and lfpprof with no tax change
for(i=1:gens)
    hoursprof=hoursprof+1/((gens+1)/2)*[ohprof(i:gens) ohprof(1:i-1)];
    lfpprof=lfpprof+1/((gens+1)/2)*[olprof(i:gens) olprof(1:i-1)];
end

%Now simulate model with taun to get hours profile for entering generations
ghmat=max(hmat-hbar,0)*(1-tau2)*step; %g(ht)*(1-tau2)*step
[hprof s2]=RWSim_iterative(hbar,mu,e0,e1,gamma,tau2,gens,svec,hvec,stp1mat,hmat,ghmat,diffmat,evec,vht,u);
hprof(time>.5)=0; %only first half of life
hprof=hprof';
lprof =(hprof>0);

%Loop through each generation and compute hours and LFP with tax = tau2
nhoursprof=zeros(1,gens);
nlfpprof=zeros(1,gens);
for(i=1:gens)
    i %output so we know status
    %run the simulation for generation that reoptimizes at age t
    [nhprof nc]=EITCSim_iterative(hbar,mu,e0,e1,gamma,tau2,gens,i,s(i),svec,hvec,stp1mat,hmat,ghmat,diffmat,evec,vht,u);
    nhprof(time>.5)=0; %only first half of life
    nhprof=nhprof';
    nlprof=(nhprof>0);
   
    %Weighting should be 1/(((gens-1)/2)+1) because only gens/2+1 generations
    %currently in first half of life
    nhoursprof=nhoursprof+1/((gens+1)/2)*[nhprof(i:gens) hprof(1:i-1)];
    nlfpprof=nlfpprof+1/((gens+1)/2)*[nlprof(i:gens) lprof(1:i-1)];
end
end
