function [hoursprof lfpprof nhoursprof nlfpprof] = IcelandSimOLG_iterative(hbar,mu,e0,e1,gamma,tau0,tau1,tau2,taulength,gens,press,presh)
%EITCSimOLG_iterative: Simulate overlapping generations of EITC using iterative methods
%hbar, mu, e0, e1, gamma, tau given, gens generations and press and presh
%precision for assets and hours

%set up matrices
%time and generations
step=1/gens;
time=0:step:1;
gens=gens+1;

%state and choice vector: assets
smin=-.05;
smax=.05;
svec=[smin:press:smax]';
ss=size(svec); ss=ss(1);

%choice vector: hours
hmin=0;
hmax=.75;
hvec=[hmin:presh:hmax]';
sh=size(hvec); sh=sh(1);

%create two dimensional matrices with st in columns and st+1 %and h in rows,
%with st+1 increasing every element and h increasing every ss elements

stmat=repmat(svec',ss*sh,1);
stp1mat=repmat(svec,sh,ss);
hmat=repmat(hvec(1),ss,ss);
for(j=2:sh)
    hmat=vertcat(hmat,hvec(j)*ones(ss));
end

%matrices--compute once and pass to EITCSim to save time
evec=e0-2*(1-e1)*abs(.5-time); %productivity at age t
ghmat0=max(hmat-hbar,0)*(1-tau0)*step; %g(ht)*(1-tau0)*step
ghmat1=max(hmat-hbar,0)*(1-tau1)*step; %g(ht)*(1-tau1)*step
ghmat2=max(hmat-hbar,0)*(1-tau2)*step; %g(ht)*(1-tau2)*step
diffmat=stmat-stp1mat; %difference between stp1 and st
vht=step*mu/(1+gamma)*(hmat.^(1+gamma));%disutility of hours (stationary)
u=@(c) log(max(c,0)); %utility

%First simulate the model for the given hbar, e0, e1, gamma, and mu to get
%the asset profile and hours/lfp profiles without the tax change
[ohprof s]=RWSim_iterative(hbar,mu,e0,e1,gamma,tau0,gens,svec,hvec,stp1mat,hmat,ghmat0,diffmat,evec,vht,u);
ohprof=ohprof';
olprof =(ohprof>0);

hoursprof=zeros(1,gens);
lfpprof=zeros(1,gens);
test=zeros(1,gens);
%compute hoursprof and lfpprof with no tax change
for(i=1:gens)
    hoursprof=hoursprof+1/gens*[ohprof(i:gens) ohprof(1:i-1)];
    lfpprof=lfpprof+1/gens*[olprof(i:gens) olprof(1:i-1)];
    test=test+1/gens*[olprof];
end

%Now simulate model with taun to get hours profile for entering generations
[ehprof s2]=RWSim_iterative(hbar,mu,e0,e1,gamma,tau2,gens,svec,hvec,stp1mat,hmat,ghmat2,diffmat,evec,vht,u);
ehprof=ehprof';
elprof =(ehprof>0);

%Loop through each generation and compute hours and LFP with tax = tau2
nhoursprof=zeros(1,gens);
nlfpprof=zeros(1,gens);
test=zeros(1,gens);
for(i=1:gens)
    i %output so we know status
    %run the simulation for generation that reoptimizes at age t

    nhprof=IcelandSim_iterative(hbar,mu,e0,e1,gamma,tau1,tau2,i,i+taulength,gens, s(i),svec,hvec,stp1mat,hmat,ghmat1,ghmat2,diffmat,evec,vht,u);
    nhprof=nhprof';
    nlprof=(nhprof>0);
    
    if(i+taulength>gens) %if you don't see the tax change back during your life, the incoming generation has the low tax for some amount of time
        nhprof2=IcelandSim_iterative(hbar,mu,e0,e1,gamma,tau1,tau2,0,i+taulength-gens,gens,0,svec,hvec,stp1mat,hmat,ghmat1,ghmat2,diffmat,evec,vht,u);
        nhprof2=nhprof2';
        nlprof2=(nhprof2>0);
        
        %add generation and generatino that replaces it on to aggregae
        %hours profile (weight generation 1/gens)
        nhoursprof=nhoursprof+(1/gens*[nhprof(i:gens) nhprof2(1:i-1)]);
        nlfpprof=nlfpprof+(1/gens*[nlprof(i:gens) nlprof2(1:i-1)]);
    else
       %add generation and generation that replaces it on to aggregate
       %hours profile (weight generation 1/gens)
       nhoursprof=nhoursprof+(1/gens*[nhprof(i:gens) ehprof(1:i-1)]);
       nlfpprof=nlfpprof+(1/gens*[nlprof(i:gens) elprof(1:i-1)]);
       test=test+(1/gens*test);
    end
end
end
